//========================================
// program.c --- ACM ICPC 2012 Domestic B
//  Created by M.Miyazaki [2013.01.13]
//========================================

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/**
 * 数値リストの最大要素数
 */
#define MAX_ELEMENTS 21

/**
 * 最大桁数
 */
#define MAX_LENGTH 6

/*
 * 関数のプロトタイプ宣言
 */
int main(int argumentCount, char * argumentValues[]);
int input(int * firstPointer, int * secondPointer);
void perform(int aValue, int numberOfDigit);
int getMaxNumber(int aValue, int numberOfDigit);
int getMinNumber(int aValue, int numberOfDigit);
void stringFromValueWithLength(char valueString[], int aValue, int length);
int getIndexOfDuplication(int valueArray[], int maxIndex);

/**
 * メインプログラム.
 *
 * @param argumentCount 引数の数
 * @param argumentValues[] 引数の値
 * @return 終了時の値（正常終了ならEXIT_SUCCESS）
 */
int main(int argumentCount, char * argumentValues[])
{
	int aValue;          // 入力された数値
	int numberOfDigit;   // 数値および桁数
	
	while (input(&aValue, &numberOfDigit) == 1)
	{
		perform(aValue, numberOfDigit);
	}
	
	return EXIT_SUCCESS;
}

/**
 * 2数の入力を担う関数.
 *
 * @param firstPointer 1つ目の値を格納するためのポインタ
 * @param secondPointer 2つ目の値を格納するためのポインタ
 * @return 「0 0」が入力された場合は0、それ以外は1を応答する。
 */
int input(int * firstPointer, int * secondPointer)
{
	int returnValue = 1;
	
	scanf("%d %d", firstPointer, secondPointer);
	
	if (*firstPointer == 0  &&  *secondPointer == 0)
	{
		returnValue = 0;
	}

	return returnValue;
}

/**
 * 数値と桁数から、問題の趣旨に沿った文字列を出力する関数.
 *
 * @param aValue 入力値（処理対象となる数値）
 * @param numberOfDigit 指定桁数
 */
void perform(int aValue, int numberOfDigit)
{
	int valueArray[MAX_ELEMENTS];   // 数値リスト
	int count = 0;                  // 数値リスト用のカウンタ
	int maxNumber, minNumber;       // 桁の入れ替えから求まる最大値と最小値
	int indexOfDuplication;         // 重複要素のインデックス
	
	for (count = 0; count < MAX_ELEMENTS; count++)
	{
		valueArray[count] = -1;
	}
	count = 0;
	valueArray[count] = aValue;
	
	while (1)
	{
		maxNumber = getMaxNumber(aValue, numberOfDigit);
		minNumber = getMinNumber(aValue, numberOfDigit);
		
		aValue = maxNumber - minNumber;
		count++;
		valueArray[count] = aValue;
		indexOfDuplication = getIndexOfDuplication(valueArray, count);
		
		if (indexOfDuplication != -1)
		{
			printf("%d ", indexOfDuplication);
			printf("%d ", valueArray[indexOfDuplication]);
			printf("%d\n", count - indexOfDuplication);
			break;
		}
	}
	
	return;
}

/**
 * 入力値の各桁を入れ替えて最大値を応答する.
 *
 * @param aValue 入力値（処理対象となる数値）
 * @param numberOfDigit 指定桁数
 * @return 最大値
 */
int getMaxNumber(int aValue, int numberOfDigit)
{
	int maxNumber;
	int index;
	char valueString[MAX_LENGTH + 1];
	
	stringFromValueWithLength(valueString, aValue, numberOfDigit);
	
	for (index = 0; index < strlen(valueString) - 1; index++)
	{
		if (valueString[index] < valueString[index + 1])
		{
			char temporaryCharacter;
			temporaryCharacter     = valueString[index];
			valueString[index]     = valueString[index + 1];
			valueString[index + 1] = temporaryCharacter;
			index = -1;
		}
	}
	
	maxNumber = atoi(valueString);
	
	return maxNumber;
}

/**
 * 入力値の各桁を入れ替えて最小値を応答する.
 *
 * @param aValue 入力値（処理対象となる数値）
 * @param numberOfDigit 指定桁数
 * @return 最小値
 */
int getMinNumber(int aValue, int numberOfDigit)
{
	int minNumber;
	int index;
	char valueString[MAX_LENGTH + 1];
	
	stringFromValueWithLength(valueString, aValue, numberOfDigit);
	
	for (index = 0; index < strlen(valueString) - 1; index++)
	{
		if (valueString[index] > valueString[index + 1])
		{
			char temporaryCharacter;
			temporaryCharacter     = valueString[index];
			valueString[index]     = valueString[index + 1];
			valueString[index + 1] = temporaryCharacter;
			index = -1;
		}
	}
	
	minNumber = atoi(valueString);
	
	return minNumber;
}

/**
 * 数値から文字列に変換して応答する。ただし、指定桁数に届かない分は先頭を0で埋める。
 *
 * @param valueString[] 変換後の文字列を格納する配列
 * @param aValue 変換元の数値
 * @param length 指定桁数
 */
void stringFromValueWithLength(char valueString[], int aValue, int length)
{
	char formatString[10];
	
	sprintf(formatString, "%%0%dd", length);
	sprintf(valueString, formatString, aValue);
	
	return;
}

/**
 * 配列中に重複要素があった場合、その要素が最初に出現するインデックスを応答する.
 *
 * @param valueArray[] 検査対象となる数値リスト
 * @param maxIndex 数値リストに対して参照できる最大のインデックス
 * @return 重複要素の格納場所を指すインデックス。重複要素がなければ-1を応答する。
 */
int getIndexOfDuplication(int valueArray[], int maxIndex)
{
	int indexOfDuplication = -1;
	int index1, index2;   // 注目している2要素を指すインデックス
	
	for (index1 = 0; index1 < maxIndex; index1++)
	{
		for (index2 = index1 + 1; index2 <= maxIndex; index2++)
		{
			if (valueArray[index1] == valueArray[index2])
			{
				// 重複要素が見つかったため、ループから脱出する。
				indexOfDuplication = index1;
				index1 = MAX_ELEMENTS;
				index2 = MAX_ELEMENTS;
			}
		}
	}
	
	return indexOfDuplication;
}
